@@ -19,7 +19,6 @@ async def index(req: Request):
             'spiders': [spider_name for spider_name in req.app.x.spiders],
             'stats': {
                 'backlog': req.app.x.redis_conn.llen(req.app.x.queue_backlog_name),
-                'running': int(req.app.x.redis_conn.get(req.app.x.queue_running_counter_name)),
                 'finished': int(req.app.x.redis_conn.get(req.app.x.queue_finished_counter_name))
             },
         }
@@ -116,7 +115,6 @@ async def enqueue(spider_name: str, req: Request, res: Response):
 async def daemonstatus(req: Request):
     return {
         "status": "ok",
-        "running": int(req.app.x.redis_conn.get(req.app.x.queue_running_counter_name)),
         "pending": req.app.x.redis_conn.llen(req.app.x.queue_name + '.BACKLOG'),
         "finished": int(req.app.x.redis_conn.get(req.app.x.queue_finished_counter_name)),
         "node_name": socket.gethostname(),
